#ifndef __iGuardAPI_h__
#define __iGuardAPI_h__

/* ***********************************************************************/
/* ***** Copyright 1999 Lucky Technolog Co., All rights reserved.   ******/
/* ***** Lucky Technology assumes no liability for errors in any of ******/
/* ***** the software it provides.                                  ******/
/* ***********************************************************************/

/* ************************ iGuard.h version 1.0.0 ******************/
/* 
   This file is used for interface application program and 
   iGuard API Library
*/
/* ****************************************************************/

#ifndef IGUARD_VERSION
#define IGUARD_VERSION 2.0
#endif

#include "winapr.h"
#include "database.h"

#ifdef __cplusplus
extern "C" {
#endif

//////////////////// CALL BACK FUNCTION TYPE DEFINE //////////////////// 
typedef void CALLBACK ProgressCallbackFunc(int nPercentage);		//Callback function for displaying progress
typedef void CALLBACK RecvAccessLogFunc(LPDB_TIMELOG pAccessLog);	//Callback function for Access Log Received (In Server Mode Only)

//Options for database update
#define DB_UPDOPT_SAVEPASSWORD 1	//Save with new password when update a user record

//iGuard Events ID
#define IGM_STARTSERVER	1
#define IGM_STOPSERVER	2

//////////////////// FUNCTION TYPE DECLARATION //////////////////// 	
//API general functions
CDECL_DLL(BOOL) iGuard_Initialize(HWND hWnd, BOOL bShowMsg, BOOL bShowLogin, DWORD dwWndMsg);
CDECL_DLL(BOOL) iGuard_CreateTrayIcon(UINT uCallbackMessage, LPCTSTR szToolTips, HICON hIcon, UINT uID);
CDECL_DLL(BOOL) iGuard_SetTrayIconText(LPCTSTR szToolTips);
CDECL_DLL(BOOL) iGuard_Exit(void);
CDECL_DLL(void) iGuard_AboutDLL();
CDECL_DLL(void) iGuard_CreateDefaultConfig();
CDECL_DLL(void) iGuard_SaveConfig();
CDECL_DLL(LPCTSTR) iGuard_DLLVersion();
CDECL_DLL(DWORD) ConvertToIP(LPCSTR lpzUrl);

//iGuard control function
CDECL_DLL(BOOL) iGuard_GetTerminalName(LPCTSTR lpzUrl, LPTSTR lpzBuffer, int nMaxLen);
CDECL_DLL(BOOL) iGuard_GetVersion(LPCTSTR lpzUrl, LPTSTR lpzBuffer, int nMaxLen);
CDECL_DLL(BOOL) iGuard_Unlock(LPCTSTR lpzUrl);
CDECL_DLL(BOOL) iGuard_SetDateTime(LPCTSTR lpzUrl, PSYSTEMTIME lpTime);
CDECL_DLL(BOOL) iGuard_Reboot(LPCTSTR lpzUrl);
CDECL_DLL(BOOL) iGuard_Login(LPCTSTR lpzUrl, LPCTSTR lpzUserName, LPCTSTR lpzPassword);
CDECL_DLL(void) iGuard_Logout(void);
CDECL_DLL(BOOL) iGuard_LoginDialogBox(LPCTSTR lpzUrl);
CDECL_DLL(BOOL) iGuard_GetLogin(LPCTSTR lpzUrl, LPTSTR lpzUserName, LPTSTR lpzPassword);
CDECL_DLL(DWORD) iGuard_GetMasterIP(LPCTSTR lpzUrl);
CDECL_DLL(BOOL) iGuard_IsMaster(LPCTSTR lpzUrl);
CDECL_DLL(BOOL) iGuard_GetSerialNo(LPCTSTR lpzUrl, LPTSTR lpzBuffer, int nMaxLen);
CDECL_DLL(LPCTSTR) iGuard_GetErrorMessage(int nErrorCode);
CDECL_DLL(int) iGuard_GetLastError(void);
CDECL_DLL(void) iGuard_SetProgressCallback(ProgressCallbackFunc *pCallback);

// iGuard Response Server API functions  
CDECL_DLL(BOOL) iGuard_IsServerStarted(void);
CDECL_DLL(BOOL) iGuard_StartServer(RecvAccessLogFunc *pCallback);
CDECL_DLL(BOOL) iGuard_StartServerWithAutoLog(LPCTSTR lpzLogFile);
CDECL_DLL(BOOL) iGuard_StopServer(void);
CDECL_DLL(BOOL) iGuard_RegisterServer(LPCTSTR lpzUrl, BOOL bLogin);
CDECL_DLL(BOOL) iGuard_UnRegisterServer(LPCTSTR lpzUrl);
CDECL_DLL(BOOL) iGuard_SetServerPort(unsigned short nPort, BOOL bRestart);
CDECL_DLL(unsigned short) iGuard_GetServerPort(void);
CDECL_DLL(void) iGuard_SetRecvAccessLogCallbackFunc(RecvAccessLogFunc *pCallback);
CDECL_DLL(void) iGuard_SetServerAutoStart(BOOL bAutoStart);
CDECL_DLL(BOOL) iGuard_GetServerAutoStart(void);
CDECL_DLL(BOOL) iGuard_ShowServerIcon(BOOL bShow);

// RAS functions
CDECL_DLL(BOOL) iGuard_RasInitialize(BOOL bShowMenu);
CDECL_DLL(BOOL) iGuard_RasDialUp(LPCTSTR lpzEntryName, LPCTSTR lpzUserName, LPCTSTR lpzPassword, BOOL bShowDialog);
CDECL_DLL(BOOL) iGuard_RasPhoneBook(LPTSTR lpzPhoneBook, int nMaxLen);
CDECL_DLL(BOOL) iGuard_RasSetLogin(LPCTSTR lpzEntryName, LPCTSTR lpzUserName, LPCTSTR lpzPassword);
CDECL_DLL(BOOL) iGuard_RasIsConnected(DWORD *dwConnectionStatus);
CDECL_DLL(BOOL) iGuard_RasScheduleConfig(void);
CDECL_DLL(BOOL) iGuard_RasScheduleInitialize(void);
CDECL_DLL(BOOL) iGuard_RasScheduler(BOOL bStart);

//Database Commands
CDECL_DLL(BOOL) iGuard_DatabaseTerminalList(LPCTSTR lpzUrl, LPTSTR lpzTerminalList, int nMaxLen, int *nListLen);
CDECL_DLL(BOOL) iGuard_DatabaseDepartmentList(LPCTSTR lpzUrl, LPTSTR lpzDepartmentList, int nMaxLen, int *nListLen);
CDECL_DLL(BOOL) iGuard_DatabaseEmployeeList(LPCTSTR lpzUrl, LPTSTR lpzEmployeeList, int nMaxLen, int *nListLen);
CDECL_DLL(BOOL) iGuard_DatabaseIOTriggerList(LPCTSTR lpzUrl, LPTSTR lpzIOTriggerList, int nMaxLen, int *nListLen);
CDECL_DLL(BOOL) iGuard_DatabaseHolidayList(LPCTSTR lpzUrl, LPTSTR lpzHolidayList, int nMaxLen, int *nListLen);
CDECL_DLL(BOOL) iGuard_DatabaseFirst(LPCTSTR lpzUrl, LPCTSTR lpzDatabaseName, LPTSTR pRecord, int nMaxLen);
CDECL_DLL(BOOL) iGuard_DatabasePrevious(LPCTSTR lpzUrl, LPCTSTR lpzDatabaseName, LPTSTR pRecord, int nMaxLen);
CDECL_DLL(BOOL) iGuard_DatabaseNext(LPCTSTR lpzUrl, LPCTSTR lpzDatabaseName, LPTSTR pRecord, int nMaxLen);
CDECL_DLL(BOOL) iGuard_DatabaseLast(LPCTSTR lpzUrl, LPCTSTR lpzDatabaseName, LPTSTR pRecord, int nMaxLen);
CDECL_DLL(BOOL) iGuard_DatabaseFind(LPCTSTR lpzUrl, LPCTSTR lpzDatabaseName, LPCTSTR lpzID, LPTSTR pRecord, int nMaxLen);
CDECL_DLL(BOOL) iGuard_DatabaseDeleteAccessLog(LPCTSTR lpzUrl, LPCTSTR lpzID, const FILETIME *lpFileTime);
CDECL_DLL(BOOL) iGuard_DatabaseDelete(LPCTSTR lpzUrl, LPCTSTR lpzDatabaseName, LPCTSTR lpzID);
CDECL_DLL(BOOL) iGuard_DatabaseInsert(LPCTSTR lpzUrl, LPCTSTR lpzDatabaseName, LPTSTR pRecord, int nMaxLen);
CDECL_DLL(BOOL) iGuard_DatabaseUpdate(LPCTSTR lpzUrl, LPCTSTR lpzDatabaseName, LPTSTR pRecord, int nMaxLen, int nOption);
CDECL_DLL(int) iGuard_DatabaseRecordCount(LPCTSTR lpzUrl, LPCTSTR lpzDatabaseName);
CDECL_DLL(BOOL) iGuard_DatabaseGetOptions(LPCTSTR lpzUrl, LPCTSTR lpzDatabaseName, LPCTSTR lpzID, LPTSTR pOptions, int nMaxLen);
CDECL_DLL(BOOL) iGuard_DatabaseSaveOptions(LPCTSTR lpzUrl, LPCTSTR lpzDatabaseName, LPCTSTR lpzID, LPCTSTR pOptions);
CDECL_DLL(BOOL) iGuard_DatabaseCheckRestriction(void *pDepartmentRecord, int nLen, int nDay, int nHour, int nMinute);
CDECL_DLL(BOOL) iGuard_DatabaseSetRestriction(void *pDepartmentRecord, int nLen, int nDay, int nHour, int nMinute, BOOL bEnable);
CDECL_DLL(BOOL) iGuard_DatabaseAddHoliday(LPCTSTR lpzUrl, LPCTSTR lpzDate);
CDECL_DLL(BOOL) iGuard_DatabaseRemoveHoliday(LPCTSTR lpzUrl, LPCTSTR lpzDate);
CDECL_DLL(BOOL) iGuard_DatabaseAddIOTrigger(LPCTSTR lpzUrl, LPCTSTR lpzTime, BOOL bIn);
CDECL_DLL(BOOL) iGuard_DatabaseRemoveIOTrigger(LPCTSTR lpzUrl, LPCTSTR lpzTime);

// Export Definition
typedef struct EXPORT_DEFINITION_T {
    int nSize;              //Size of sturct, for version checking
	int nReport;			// 0 = Access Log, 1 = Attendance Report
	int nFormat;			// 0 = TXT Format, 1 = XLS Format
	BOOL bIncludeHeader;

	char szID[17];
	char szDepartment[17];
	int nPeriod;			//0 = All, 1 = Range, 2 = Today, 3 = Yesterday, 
							//4 = This week, 5 = Last week, 6 = This month, 7 = Last month
	char szDateFrom[16];	//MM/DD/YYYY
	char szDateTo[16];		//MM/DD/YYYY
} EXPORT_DEFINITION, *LPEXPORT_DEFINITION;
	
CDECL_DLL(BOOL) iGuard_Export(LPCTSTR lpzUrl, LPCTSTR lpzFileName, LPEXPORT_DEFINITION pDefinition);
CDECL_DLL(BOOL) iGuard_BackupDatabase(LPCTSTR lpzUrl, LPCTSTR lpzFileName);
CDECL_DLL(BOOL) iGuard_RestoreDatabase(LPCTSTR lpzUrl, LPCTSTR lpzFileName);

#ifdef __cplusplus
}
#endif



#endif __iGuardAPI_h__


