#ifndef __iGuardAPI_h__
#define __iGuardAPI_h__

/* ***********************************************************************/
/* ***** Copyright 1999 Lucky Technolog Co., All rights reserved.   ******/
/* ***** Lucky Technology assumes no liability for errors in any of ******/
/* ***** the software it provides.                                  ******/
/* ***********************************************************************/

/* ************************ iGuard.h version 1.0.0 ******************/
/* 
   This file is used for interface application program and 
   iGuard API Library
*/
/* ****************************************************************/

#ifndef IGUARD_VERSION
#define IGUARD_VERSION 2.0
#endif

#include "winapr.h"
#include "database.h"


#ifdef __cplusplus
extern "C" {
#endif

//
// Structure TERMINALINFO
//
typedef struct TERMINALINFO_T {
	char Header[7];
	char HostName[20];
	DWORD SerialNo;
	DWORD IP;
	DWORD MasterIP;
	DWORD Version;
	DWORD Status;

	char Description[40];
	char OtherInfo1[10];
	char OtherInfo2[10];
} TERMINALINFO, *LPTERMINALINFO;

//
// Definition for Status in structure TERMINALINFO
//
#define STATUS_ISMASTER     0x00000001
#define STATUS_DHCP		    0x00010000
#define STATUS_ALARM		0x10000000

//////////////////// CALL BACK FUNCTION TYPE DEFINE //////////////////// 
typedef void CALLBACK ProgressCallbackFunc(int nPercentage);		//Callback function for displaying progress
typedef void CALLBACK RecvAccessLogFunc(LPDB_TIMELOG pAccessLog);	//Callback function for Access Log Received (In Server Mode Only)
//typedef void CALLBACK TerminalRegistrationFunc(LPDB_TERMINALS pTerminalInfo);
typedef void CALLBACK TerminalRegistrationFunc(LPBROADCASTINFOEX pTerminalInfo);
typedef LRESULT CALLBACK TerminalMessageFunc(void *pParam);

//Options for database update
#define DB_UPDOPT_SAVEPASSWORD		1	// Save with new password when update a user record
#define DB_UPDOPT_CHANGEEMPLOYEEID	2	// Update Employee ID

//iGuard Events ID
#define IGM_STARTSERVER			1
#define IGM_STOPSERVER			2
#define IGM_BROADCAST			3
#define IGM_BROADCASTERR		4
#define IGM_IGUARDOFFLINE		5
#define IGM_IGUARDONLINE		6
#define IGM_IGUARDUNREGISTER	7
#define IGM_REMOTEMESSAGE		8
#define IGM_BRDCSTSYNCTIME		9
#define IGM_LOGBUFFERFULL		51
#define IGM_NOMOREACCESSLOG		52
#define IGM_ERRORMESSAGE		99

//
// Constant for Setting In/Out Trigger with function
// iGuard_SetInOutTrigger(), IOTRIGGER_SET_x set the IN/OUT
// mark if the iGuard's 'Default In/Out' in configure page
// is set to 'Follow In/Out Trigger'.  With IOTRIGGER_OVERRIDE_x,
// the In/Out trigger will ignore this setting.
//
#define IOTRIGGER_SET_IN		0
#define IOTRIGGER_SET_OUT		1
#define IOTRIGGER_OVERRIDE_IN	2
#define IOTRIGGER_OVERRIDE_OUT	3


//////////////////// FUNCTION TYPE DECLARATION //////////////////// 	
//API general functions
DECL_DLL(BOOL) iGuard_Initialize(HWND hWnd, BOOL bShowMsg, BOOL bShowLogin, DWORD dwWndMsg);
DECL_DLL(BOOL) iGuard_CreateTrayIcon(UINT uCallbackMessage, LPCTSTR szToolTips, HICON hIcon, UINT uID);
DECL_DLL(BOOL) iGuard_SetTrayIconText(LPCTSTR szToolTips);
DECL_DLL(BOOL) iGuard_SetTrayIcon(HICON hIcon);
DECL_DLL(BOOL) iGuard_Exit(void);
DECL_DLL(void) iGuard_AboutDLL();
DECL_DLL(void) iGuard_CreateDefaultConfig();
DECL_DLL(void) iGuard_SaveConfig();
DECL_DLL(void) iGuard_LoadConfig();
DECL_DLL(LPCTSTR) iGuard_DLLVersion(); 

DECL_DLL(DWORD) ConvertToIP(LPCSTR lpzUrl);
DECL_DLL(void) ConvertToURLString(LPTSTR lpzString);
DECL_DLL(void) ConvertURLToString(LPTSTR lpzString);

DECL_DLL(void) iGuard_GetSerialFromTerminalInfo(LPTERMINALINFO lpTerminalInfo, LPTSTR lpzSerialNo);
DECL_DLL(void) iGuard_GetVersionFromTermianlInfo(LPTERMINALINFO lpTerminalInfo, LPTSTR lpzVersion);

DECL_DLL(int) iGuard_AddCustomMenu(LPCTSTR szMenuText, DWORD dwCommand, DWORD dwID);

//iGuard control function
DECL_DLL(BOOL) iGuard_GetTerminalName(LPCTSTR lpzUrl, LPTSTR lpzBuffer, int nMaxLen);

DECL_DLL(BOOL) iGuard_SetTerminalName(LPCTSTR lpzUrl, LPCTSTR lpzNewName, LPCTSTR lpzDescription);
DECL_DLL(BOOL) iGuard_SetTerminalIP(LPCTSTR lpzUrl, BOOL bDHCP, LPCTSTR lpzNewIP);
DECL_DLL(BOOL) iGuard_SetTerminalIPEx(LPCTSTR lpzUrl, LPCTSTR lpzSubnetMask, BOOL bDHCP, LPCTSTR lpzNewIP);
DECL_DLL(BOOL) iGuard_SetTerminalInfo(LPCTSTR lpzUrl, LPCTSTR lpzNewName, LPCTSTR lpzDescription, BOOL bDHCP, LPCTSTR lpzNewIP, LPCTSTR lpzSubnetMask);

DECL_DLL(BOOL) iGuard_GetVersion(LPCTSTR lpzUrl, LPTSTR lpzBuffer, int nMaxLen);
DECL_DLL(BOOL) iGuard_GetModelName(LPCTSTR lpzUrl, LPTSTR lpzModelName, int nMaxLen);
DECL_DLL(BOOL) iGuard_GetTerminalInfo(LPCTSTR lpzUrl, LPTERMINALINFO lpTerminalInfo);
DECL_DLL(BOOL) iGuard_Unlock(LPCTSTR lpzUrl);
DECL_DLL(BOOL) iGuard_SetDateTime(LPCTSTR lpzUrl, PSYSTEMTIME lpTime);
DECL_DLL(BOOL) iGuard_GetDateTime(LPCTSTR lpzUrl, PSYSTEMTIME lpTime);
DECL_DLL(BOOL) iGuard_SynchronizeDateTime(LPCTSTR lpzUrl);
DECL_DLL(BOOL) iGuard_Reboot(LPCTSTR lpzUrl);
DECL_DLL(BOOL) iGuard_Shutdown(LPCTSTR lpzUrl);
DECL_DLL(BOOL) iGuard_SendRemoteMessage(LPCTSTR lpzUrl, unsigned short nPort, LPCTSTR szLoginName, LPCTSTR szPassword, LPCTSTR szMsg);
DECL_DLL(BOOL) iGuard_Login(LPCTSTR lpzUrl, LPCTSTR lpzUserName, LPCTSTR lpzPassword);
DECL_DLL(void) iGuard_Logout(void);
DECL_DLL(BOOL) iGuard_LoginDialogBox(LPCTSTR lpzUrl);
DECL_DLL(BOOL) iGuard_GetLogin(LPCTSTR lpzUrl, LPTSTR lpzUserName, LPTSTR lpzPassword);
DECL_DLL(DWORD) iGuard_GetMasterIP(LPCTSTR lpzUrl);
DECL_DLL(BOOL) iGuard_SetMasterIP(LPCTSTR lpzUrl, LPCTSTR lpzMasterIP);
DECL_DLL(BOOL) iGuard_IsMaster(LPCTSTR lpzUrl);
DECL_DLL(BOOL) iGuard_GetSerialNo(LPCTSTR lpzUrl, LPTSTR lpzBuffer, int nMaxLen);
DECL_DLL(LPCTSTR) iGuard_GetErrorMessage(int nErrorCode);
DECL_DLL(int) iGuard_GetLastError(void);
DECL_DLL(BOOL) iGuard_ResetRestriction(LPCTSTR lpzUrl);
DECL_DLL(BOOL) iGuard_SetInOutTrigger(LPCTSTR lpzUrl, int nState);
DECL_DLL(BOOL) iGuard_ShowMessage(LPCTSTR lpzUrl, LPCTSTR lpzUpperMsg, LPCTSTR lpzLowerMsg, int nDuration);

//
// Event id for function iGuard_SetEventMessage 
//
#define EVENT_SHOWPROGRESS			0
#define EVENT_RECVACCESSLOG			1
#define EVENT_RESERVED_1			2
#define EVENT_REQMINUTIAE			3
#define EVENT_SAVEMINUTIAE			4
#define EVENT_TERMINALREGISTRATION	5
#define EVENT_RESERVED_2			9
#define EVENT_TERMINALMESSAGE		11
#define EVENT_TERMINALCASEOPEN		12
#define EVENT_ADMINEVENT			13
#define EVENT_TERMINALEVENT			14

DECL_DLL(BOOL) iGuard_SetEventMessage(int nEvent, DWORD dwMsgNo);
DECL_DLL(void) iGuard_SetProgressCallback(ProgressCallbackFunc *pCallback);
DECL_DLL(void) iGuard_SetTerminalRegistrationCallback(TerminalRegistrationFunc pCallback);
DECL_DLL(void) iGuard_SetTerminalMessageCallback(TerminalMessageFunc pCallback);

DECL_DLL(DWORD) iGuard_GetIP(LPCTSTR lpzTerminalName);

// iGuard Response Server API functions  
DECL_DLL(BOOL) iGuard_IsServerStarted(void);
DECL_DLL(BOOL) iGuard_StartServer(RecvAccessLogFunc *pCallback);
DECL_DLL(BOOL) iGuard_StartServerWithAutoLog(LPCTSTR lpzLogFile);
DECL_DLL(BOOL) iGuard_StopServer(void);
DECL_DLL(BOOL) iGuard_RegisterServer(LPCTSTR lpzUrl, BOOL bLogin);
DECL_DLL(BOOL) iGuard_UnRegisterServer(LPCTSTR lpzUrl);
DECL_DLL(BOOL) iGuard_SetServerPort(unsigned short nPort, BOOL bRestart);
DECL_DLL(unsigned short) iGuard_GetServerPort(void);
DECL_DLL(void) iGuard_SetRecvAccessLogCallbackFunc(RecvAccessLogFunc *pCallback);
DECL_DLL(void) iGuard_SetServerAutoStart(BOOL bAutoStart);
DECL_DLL(BOOL) iGuard_GetServerAutoStart(void);
DECL_DLL(BOOL) iGuard_ShowServerIcon(BOOL bShow);
DECL_DLL(BOOL) iGuard_GetTerminalServerInfo(LPCTSTR lpzUrl, LPTSTR lpzServerName, DWORD *lpdwServerIP);
DECL_DLL(BOOL) iGuard_GetTerminalStatusLog(LPCTSTR lpzUrl, int nLogNum, LPCTSTR szFileName);
DECL_DLL(BOOL) iGuard_EnableAuthenticationEvent(LPCTSTR lpzUrl, BOOL bEnable);

// RAS functions
DECL_DLL(BOOL) iGuard_RasInitialize(BOOL bShowMenu);
DECL_DLL(BOOL) iGuard_RasDialUp(LPCTSTR lpzEntryName, LPCTSTR lpzUserName, LPCTSTR lpzPassword, BOOL bShowDialog);
DECL_DLL(BOOL) iGuard_RasPhoneBook(LPTSTR lpzPhoneBook, int nMaxLen);
DECL_DLL(BOOL) iGuard_RasSetLogin(LPCTSTR lpzEntryName, LPCTSTR lpzUserName, LPCTSTR lpzPassword);
DECL_DLL(BOOL) iGuard_RasIsConnected(DWORD *dwConnectionStatus);
DECL_DLL(BOOL) iGuard_RasScheduleConfig(void);
DECL_DLL(BOOL) iGuard_RasScheduleInitialize(void);
DECL_DLL(BOOL) iGuard_RasScheduler(BOOL bStart);

//Database Commands
DECL_DLL(BOOL) iGuard_DatabaseTerminalList(LPCTSTR lpzUrl, LPTSTR lpzTerminalList, int nMaxLen, int *nListLen);
DECL_DLL(BOOL) iGuard_DatabaseDepartmentList(LPCTSTR lpzUrl, LPTSTR lpzDepartmentList, int nMaxLen, int *nListLen);
DECL_DLL(BOOL) iGuard_DatabaseEmployeeList(LPCTSTR lpzUrl, LPTSTR lpzEmployeeList, int nMaxLen, int *nListLen);
DECL_DLL(BOOL) iGuard_DatabaseIOTriggerList(LPCTSTR lpzUrl, LPTSTR lpzIOTriggerList, int nMaxLen, int *nListLen);
DECL_DLL(BOOL) iGuard_DatabaseHolidayList(LPCTSTR lpzUrl, LPTSTR lpzHolidayList, int nMaxLen, int *nListLen);
DECL_DLL(BOOL) iGuard_DatabaseFirst(LPCTSTR lpzUrl, LPCTSTR lpzDatabaseName, LPTSTR pRecord, int nMaxLen);
DECL_DLL(BOOL) iGuard_DatabasePrevious(LPCTSTR lpzUrl, LPCTSTR lpzDatabaseName, LPTSTR pRecord, int nMaxLen);
DECL_DLL(BOOL) iGuard_DatabaseNext(LPCTSTR lpzUrl, LPCTSTR lpzDatabaseName, LPTSTR pRecord, int nMaxLen);
DECL_DLL(BOOL) iGuard_DatabaseLast(LPCTSTR lpzUrl, LPCTSTR lpzDatabaseName, LPTSTR pRecord, int nMaxLen);
DECL_DLL(BOOL) iGuard_DatabaseFind(LPCTSTR lpzUrl, LPCTSTR lpzDatabaseName, LPCTSTR lpzID, LPTSTR pRecord, int nMaxLen);
DECL_DLL(BOOL) iGuard_DatabaseDeleteAccessLog(LPCTSTR lpzUrl, LPCTSTR lpzID, const FILETIME *lpFileTime);
DECL_DLL(BOOL) iGuard_DatabaseDelete(LPCTSTR lpzUrl, LPCTSTR lpzDatabaseName, LPCTSTR lpzID);
DECL_DLL(BOOL) iGuard_DatabaseInsert(LPCTSTR lpzUrl, LPCTSTR lpzDatabaseName, LPTSTR pRecord, int nMaxLen);
DECL_DLL(BOOL) iGuard_DatabaseUpdate(LPCTSTR lpzUrl, LPCTSTR lpzDatabaseName, LPTSTR pRecord, int nMaxLen, int nOption);
DECL_DLL(int) iGuard_DatabaseRecordCount(LPCTSTR lpzUrl, LPCTSTR lpzDatabaseName);
DECL_DLL(BOOL) iGuard_DatabaseGetOptions(LPCTSTR lpzUrl, LPCTSTR lpzDatabaseName, LPCTSTR lpzID, LPTSTR pOptions, int nMaxLen);
DECL_DLL(BOOL) iGuard_DatabaseSaveOptions(LPCTSTR lpzUrl, LPCTSTR lpzDatabaseName, LPCTSTR lpzID, LPCTSTR pOptions);
DECL_DLL(BOOL) iGuard_DatabaseCheckRestriction(void *pDepartmentRecord, int nLen, int nDay, int nHour, int nMinute);
DECL_DLL(BOOL) iGuard_DatabaseSetRestriction(void *pDepartmentRecord, int nLen, int nDay, int nHour, int nMinute, BOOL bEnable);
DECL_DLL(BOOL) iGuard_DatabaseAddHoliday(LPCTSTR lpzUrl, LPCTSTR lpzDate);
DECL_DLL(BOOL) iGuard_DatabaseRemoveHoliday(LPCTSTR lpzUrl, LPCTSTR lpzDate);
DECL_DLL(BOOL) iGuard_DatabaseAddIOTrigger(LPCTSTR lpzUrl, LPCTSTR lpzTime, BOOL bIn);
DECL_DLL(BOOL) iGuard_DatabaseRemoveIOTrigger(LPCTSTR lpzUrl, LPCTSTR lpzTime);
DECL_DLL(BOOL) iGuard_DatabasePurgeAccessLog(LPCTSTR lpzUrl);
DECL_DLL(BOOL) iGuard_DatabasePurgeUser(LPCTSTR lpzUrl);
DECL_DLL(BOOL) iGuard_DatabasePurgeAll(LPCTSTR lpzUrl);
DECL_DLL(BOOL) iGuard_HardReset(LPCTSTR lpzUrl, int nDbToReset);

// Export Definition
typedef struct EXPORT_DEFINITION_T {
    int nSize;              //Size of sturct, for version checking
	int nReport;			// 0 = Access Log, 1 = Attendance Report, 2 = Daily In/Out Report
	int nFormat;			// 0 = TXT Format, 1 = XLS Format
	BOOL bIncludeHeader;

	char szID[17];
	char szDepartment[17];
	int nPeriod;			//0 = All, 1 = Range, 2 = Today, 3 = Yesterday, 
							//4 = This week, 5 = Last week, 6 = This month, 7 = Last month
	char szDateFrom[16];	//MM/DD/YYYY
	char szDateTo[16];		//MM/DD/YYYY
} EXPORT_DEFINITION, *LPEXPORT_DEFINITION;
	
DECL_DLL(BOOL) iGuard_Export(LPCTSTR lpzUrl, LPCTSTR lpzFileName, LPEXPORT_DEFINITION pDefinition);
DECL_DLL(BOOL) iGuard_BackupDatabase(LPCTSTR lpzUrl, LPCTSTR lpzFileName);
DECL_DLL(BOOL) iGuard_RestoreDatabase(LPCTSTR lpzUrl, LPCTSTR lpzFileName);

#define CONFIG_USE_PING					0x10000001
#define CONFIG_ENABLE_PING_TEMPORARY	0x20000001

#define CONFIG_TYPE_DWORD	0x00000000
#define CONFIG_TYPE_STRING	0x00000001
#define CONFIG_TYPE_CHAR	0x00000002
#define CONFIG_TYPE_INT		0x00000003
#define CONFIG_TYPE_BOOL	0x00000004

DECL_DLL(DWORD) iGuard_SetConfiguration(DWORD dwOptionID, void *lpSetting);
DECL_DLL(DWORD) iGuard_QueryConfiguration(DWORD dwOptionID, void *lpSetting, DWORD *lpSettingType);


#ifdef __cplusplus
}
#endif



#endif __iGuardAPI_h__


